@@ -6,7 +6,7 @@ pub mod string;
 pub mod utils;
 
 use crate::{
-  ast::{ErrorToken, Expression, UnaryExpression, UnaryOperator, Value},
+  ast::{ErrorToken, Expression, Path, UnaryExpression, UnaryOperator, Value},
   parser::{
     absolute_time::{date_time, date_value},
     binary_expression::binary_expr,
@@ -72,7 +72,9 @@ pub(crate) fn expr(i: LocatedSpan) -> IResult<Expression> {
 pub(crate) fn simple_expr(i: LocatedSpan) -> IResult<Expression> {
   delimited(
     multispace0,
-    alt((unary_expr, path, paren_expr, value_expr, path_start, error)),
+    alt((
+      unary_expr, path_expr, paren_expr, value_expr, path_start, error,
+    )),
     multispace0,
   )(i)
 }
@@ -102,8 +104,12 @@ fn paren_expr(i: LocatedSpan) -> IResult<Expression> {
   })(i)
 }
 
-fn path(i: LocatedSpan) -> IResult<Expression> {
-  map(many1(path_element), Expression::Path)(i)
+fn path_expr(i: LocatedSpan) -> IResult<Expression> {
+  map(path, Expression::Path)(i)
+}
+
+fn path(i: LocatedSpan) -> IResult<Path> {
+  many1(path_element)(i)
 }
 
 fn path_element(i: LocatedSpan) -> IResult<String> {
@@ -183,6 +189,18 @@ pub fn is_valid_identifier(i: &str) -> bool {
   all_parsed && errors.into_inner().is_empty()
 }
 
+pub fn parse_path<'a>(i: &'a str) -> (Path, Vec<Error>) {
+  let errors = RefCell::new(Vec::new());
+  let input = LocatedSpan::new_extra(i, State::new(&errors));
+  let (_, expr) = all_consuming(path)(input)
+    .map_err(|err| {
+      println!("Errors: {:?}", errors);
+      err
+    })
+    .expect("parser cannot fail");
+  (expr, errors.into_inner())
+}
+
 pub fn parse_filter<'a>(i: &'a str) -> (Expression, Vec<Error>) {
   let errors = RefCell::new(Vec::new());
   let input = LocatedSpan::new_extra(i, State::new(&errors));
